To enable continuous GPS tracking, it is recommended:

- Consult legal counsel on the legality of GPS tracking
- Notify user of the reason requiring GPS tracking with the possibility for users to opt-out
- Avoid storage of GPS location locally, and if needed encrypt GPS with device specific key 
